@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.72';
+$Test::BDD::Cucumber::Executor::VERSION = '0.73';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =head1 DESCRIPTION
 
@@ -243,9 +243,16 @@ sub execute_outline {
 
 
     foreach my $rows (@datasets) {
+
         my $outline_state = {};
 
         foreach my $row (@{$rows->data}) {
+
+            my $name = $outline->{name} || "";
+            $name =~ s/\Q<$_>\E/$row->{$_}/g
+                for (keys %$row);
+            local $outline->{name} = $name;
+
             $self->execute_scenario(
                 {
                     feature => $feature,
